#include "../UI/EWAGLRendererConfigurationWidget.h"
#include "EWAGLRendererConfiguration.h"

EWAGLRendererConfiguration::EWAGLRendererConfiguration() 
 : cutOffRadius(1.0f),
   gaussRadius(1.0f),
   configurationWidget(0)
{
//
}

QWidget* EWAGLRendererConfiguration::createConfigurationWidget (QWidget *parent) {
	
	configurationWidget = new EWAGLRendererConfigurationWidget (parent);

	// initialize the configuration widget
	configurationWidget->cutOffRadiusLineEdit->setText (QString::number (cutOffRadius));
    configurationWidget->gaussRadiusLineEdit->setText (QString::number (gaussRadius));
	
	return configurationWidget;
}

void EWAGLRendererConfiguration::apply() {

	float newCutOffRadius,
			newGaussRadius;
	bool  isNumber;

	newCutOffRadius = configurationWidget->cutOffRadiusLineEdit->text().toFloat (&isNumber);
	if (!isNumber || newCutOffRadius <= 0) {
		// reset value
		configurationWidget->cutOffRadiusLineEdit->setText (QString::number (cutOffRadius));
	}
	else if (newCutOffRadius != cutOffRadius) {
		cutOffRadius = newCutOffRadius;
		emit cutOffRadiusChanged (newCutOffRadius);
	}
	newGaussRadius = configurationWidget->gaussRadiusLineEdit->text().toFloat (&isNumber);
	if (!isNumber || newGaussRadius <= 0) {
		// reset value
		configurationWidget->gaussRadiusLineEdit->setText (QString::number (gaussRadius));
	}
	else if (newGaussRadius != gaussRadius) {
		gaussRadius = newGaussRadius;
		emit gaussDecayRadiusChanged(newGaussRadius);
	}


	emit configurationApplied();
}


void EWAGLRendererConfiguration::setCutOffRadius (const float newCutOffRadius) 
{
	cutOffRadius = newCutOffRadius;

	if (configurationWidget != 0) {
		configurationWidget->cutOffRadiusLineEdit->setText (QString::number (newCutOffRadius));
	}
	emit cutOffRadiusChanged (newCutOffRadius);
}

float EWAGLRendererConfiguration::getCutOffRadius() const 
{
	return cutOffRadius;
}

void EWAGLRendererConfiguration::setGaussDecayRadius (const float newGaussRadius) 
{
	gaussRadius = newGaussRadius;

	if (configurationWidget != 0) {
		configurationWidget->gaussRadiusLineEdit->setText (QString::number (newGaussRadius));
	}
	emit gaussDecayRadiusChanged (newGaussRadius);
}

float EWAGLRendererConfiguration::getGaussDecayRadius() const 
{
	return gaussRadius;
}